@@ -16,7 +16,7 @@
 #           Am Eisteich 9
 #           72555 Metzingen
 #           Germany
-# 
+#
 #           Email: joe@ispsoft.de
 #           Phone: +49 7123 14881
 #
@@ -30,7 +30,7 @@ require IO::Socket;
 
 package RPC::PlClient;
 
-$RPC::PlClient::VERSION = '0.2003';
+$RPC::PlClient::VERSION = '0.2004';
 @RPC::PlClient::ISA = qw(RPC::PlServer::Comm Net::Daemon::Log);
 
 
@@ -80,6 +80,7 @@ sub new ($@) {
     $self->Write([$app, $version, $user, $password]);
     $self->Debug("Waiting for server's response ...");
     my $reply = $self->Read();
+    die "Unexpected EOF from server" unless defined $reply;
     die "Expected server to return an array ref"
 	unless $reply && ref($reply) eq 'ARRAY';
     my $msg = defined($reply->[1]) ? $reply->[1] : '';
@@ -109,13 +110,10 @@ sub Call ($@) {
     my $self = shift;
     $self->Write([@_]);
     my $msg = $self->Read();
-    if (!$msg  ||  !ref($msg)) {
-	die "Expected server to return a reference";
-    } elsif (ref($msg) eq 'SCALAR') {
-	die "Server returned error: $$msg";
-    } elsif (ref($msg) ne 'ARRAY') {
-	die "Expected server to return an array ref";
-    }
+    die "Unexpected EOF from server" unless defined $msg;
+    die "Expected server to return a reference" unless ref($msg);
+    die "Server returned error: $$msg" if ref($msg) eq 'SCALAR';
+    die "Expected server to return an array ref" if ref($msg) ne 'ARRAY';
     @$msg;
 }
 
