@@ -14,7 +14,7 @@
 #           Am Eisteich 9
 #           72555 Metzingen
 #           Germany
-# 
+#
 #           Email: joe@ispsoft.de
 #           Phone: +49 7123 14881
 #
@@ -29,7 +29,7 @@ require RPC::PlServer::Comm;
 package RPC::PlServer;
 
 @RPC::PlServer::ISA = qw(Net::Daemon RPC::PlServer::Comm);
-$RPC::PlServer::VERSION = '0.2003';
+$RPC::PlServer::VERSION = '0.2004';
 
 
 ############################################################################
@@ -180,7 +180,7 @@ sub Run ($) {
     my $socket = $self->{'socket'};
 
     while (!$self->Done()  &&  !$socket->eof()) {
-	my $msg = $self->Read();
+	my $msg = $self->Read() || last;
 	my($error, $command);
 	if (ref($msg) ne 'ARRAY') {
 	    $error = "Expected array";
